@@ -22,6 +22,7 @@ from ._style_properties import (
     ColorProperty,
     DockProperty,
     FractionalProperty,
+    HatchProperty,
     IntegerProperty,
     KeylineProperty,
     LayoutProperty,
@@ -186,6 +187,8 @@ class RulesMap(TypedDict, total=False):
     border_subtitle_background: Color
     border_subtitle_style: Style
 
+    hatch: tuple[str, Color]
+
     overlay: Overlay
     constrain: Constrain
 
@@ -355,6 +358,8 @@ class StylesBase(ABC):
     border_subtitle_background = ColorProperty(Color(0, 0, 0, 0))
     border_subtitle_style = StyleFlagsProperty()
 
+    hatch = HatchProperty()
+
     overlay = StringEnumProperty(
         VALID_OVERLAY, "none", layout=True, refresh_parent=True
     )
@@ -1076,6 +1081,9 @@ class Styles(StylesBase):
             keyline_type, keyline_color = self.keyline
             if keyline_type != "none":
                 append_declaration("keyline", f"{keyline_type}, {keyline_color.css}")
+        if "hatch" in rules:
+            hatch_character, hatch_color = self.hatch
+            append_declaration("hatch", f'"{hatch_character}" {hatch_color.css}')
         lines.sort()
         return lines
 
