@@ -14,6 +14,7 @@ from typing import TYPE_CHECKING, Any
 import rich.repr
 
 from .. import events
+from .._parser import ParseError
 from .._xterm_parser import XTermParser
 from ..driver import Driver
 from ..geometry import Size
@@ -46,6 +47,7 @@ class LinuxDriver(Driver):
         super().__init__(app, debug=debug, mouse=mouse, size=size)
         self._file = sys.__stderr__
         self.fileno = sys.__stdin__.fileno()
+        self.input_tty = sys.__stdin__.isatty()
         self.attrs_before: list[Any] | None = None
         self.exit_event = Event()
         self._key_thread: Thread | None = None
@@ -235,7 +237,10 @@ class LinuxDriver(Driver):
             # defaults to ASCII EOT = Ctrl-D = 4.)
             newattr[tty.CC][termios.VMIN] = 1
 
-            termios.tcsetattr(self.fileno, termios.TCSANOW, newattr)
+            try:
+                termios.tcsetattr(self.fileno, termios.TCSANOW, newattr)
+            except termios.error:
+                pass
 
         self.write("\x1b[?25l")  # Hide cursor
         self.write("\x1b[?1004h")  # Enable FocusIn/FocusOut.
@@ -264,6 +269,8 @@ class LinuxDriver(Driver):
         # Terminals should ignore this sequence if not supported.
         # Apple terminal doesn't, and writes a single 'p' in to the terminal,
         # so we will make a special case for Apple terminal (which doesn't support sync anyway).
+        if not self.input_tty:
+            return
         if os.environ.get("TERM_PROGRAM", "") != "Apple_Terminal":
             self.write("\033[?2026$p")
             self.flush()
@@ -309,8 +316,11 @@ class LinuxDriver(Driver):
                 if self._key_thread is not None:
                     self._key_thread.join()
                 self.exit_event.clear()
-                termios.tcflush(self.fileno, termios.TCIFLUSH)
-        except Exception as error:
+                try:
+                    termios.tcflush(self.fileno, termios.TCIFLUSH)
+                except termios.error:
+                    pass
+        except Exception:
             # TODO: log this
             pass
 
@@ -325,13 +335,14 @@ class LinuxDriver(Driver):
             except termios.error:
                 pass
 
-            # Alt screen false, show cursor
-            self.write("\x1b[?1049l" + "\x1b[?25h")
-            self.write("\033[?1004l")  # Disable FocusIn/FocusOut.
-            self.write(
-                "\x1b[<u"
-            )  # Disable https://sw.kovidgoyal.net/kitty/keyboard-protocol/
-            self.flush()
+        # Alt screen false, show cursor
+        self.write("\x1b[?1049l")
+        self.write("\x1b[?25h")
+        self.write("\x1b[?1004l")  # Disable FocusIn/FocusOut.
+        self.write(
+            "\x1b[<u"
+        )  # Disable https://sw.kovidgoyal.net/kitty/keyboard-protocol/
+        self.flush()
 
     def close(self) -> None:
         """Perform cleanup."""
@@ -375,18 +386,26 @@ class LinuxDriver(Driver):
         utf8_decoder = getincrementaldecoder("utf-8")().decode
         decode = utf8_decoder
         read = os.read
+        eof = False
 
         try:
-            while not self.exit_event.is_set():
+            while not eof and not self.exit_event.is_set():
                 selector_events = selector.select(0.1)
                 for _selector_key, mask in selector_events:
                     if mask & EVENT_READ:
                         unicode_data = decode(
                             read(fileno, 1024), final=self.exit_event.is_set()
                         )
+                        if not unicode_data:
+                            # This can occur if the stdin is piped
+                            eof = True
+                            break
                         for event in feed(unicode_data):
                             self.process_event(event)
         finally:
             selector.close()
-            for event in feed(""):
+            try:
+                for event in feed(""):
+                    pass
+            except ParseError:
                 pass
