@@ -3,11 +3,13 @@ from __future__ import annotations
 from asyncio import gather
 from dataclasses import dataclass
 from itertools import zip_longest
+from typing import Awaitable
 
 from rich.repr import Result
 from rich.text import Text, TextType
 from typing_extensions import Final
 
+from .. import events
 from ..app import ComposeResult
 from ..await_complete import AwaitComplete
 from ..css.query import NoMatches
@@ -195,6 +197,10 @@ class TabPane(Widget):
     class Enabled(TabPaneMessage):
         """Sent when a tab pane is enabled via its reactive `disabled`."""
 
+    @dataclass
+    class Focused(TabPaneMessage):
+        """Sent when a child widget is focused."""
+
     def __init__(
         self,
         title: TextType,
@@ -223,17 +229,20 @@ class TabPane(Widget):
         """Notify the parent `TabbedContent` that a tab pane was enabled/disabled."""
         self.post_message(self.Disabled(self) if disabled else self.Enabled(self))
 
+    def _on_descendant_focus(self, event: events.DescendantFocus):
+        """Tell TabbedContent parent something is focused in this pane."""
+        self.post_message(self.Focused(self))
+
 
 class TabbedContent(Widget):
     """A container with associated tabs to toggle content visibility."""
 
     DEFAULT_CSS = """
-
     TabbedContent {
         height: auto;
-    }
-    TabbedContent Tabs {
-        dock: top;
+        &> ContentTabs {
+            dock: top;
+        }
     }
     """
 
@@ -276,7 +285,11 @@ class TabbedContent(Widget):
             yield self.pane
 
     class Cleared(Message):
-        """Posted when there are no more tab panes."""
+        """Posted when no tab pane is active.
+
+        This can happen if all tab panes are removed or if the currently active tab
+        pane is unset.
+        """
 
         def __init__(self, tabbed_content: TabbedContent) -> None:
             """Initialize message.
@@ -329,22 +342,6 @@ class TabbedContent(Widget):
             return None
         return self.get_pane(self.active)
 
-    def validate_active(self, active: str) -> str:
-        """It doesn't make sense for `active` to be an empty string.
-
-        Args:
-            active: Attribute to be validated.
-
-        Returns:
-            Value of `active`.
-
-        Raises:
-            ValueError: If the active attribute is set to empty string when there are tabs available.
-        """
-        if not active and self.get_child_by_type(ContentSwitcher).current:
-            raise ValueError("'active' tab must not be empty string.")
-        return active
-
     @staticmethod
     def _set_id(content: TabPane, new_id: int) -> TabPane:
         """Set an id on the content, if not already present.
@@ -449,7 +446,7 @@ class TabbedContent(Widget):
             An optionally awaitable object that waits for the pane to be removed
                 and the Cleared message to be posted.
         """
-        removal_awaitables = [
+        removal_awaitables: list[Awaitable] = [
             self.get_child_by_type(ContentTabs).remove_tab(
                 ContentTab.add_prefix(pane_id)
             )
@@ -465,16 +462,10 @@ class TabbedContent(Widget):
             # other means; so allow that to be a no-op.
             pass
 
-        async def _remove_content(cleared_message: TabbedContent.Cleared) -> None:
+        async def _remove_content() -> None:
             await gather(*removal_awaitables)
-            if self.tab_count == 0:
-                self.post_message(cleared_message)
 
-        # Note that I create the Cleared message out here, rather than in
-        # _remove_content, to ensure that the message's internal
-        # understanding of who the sender is is correct.
-        # https://github.com/Textualize/textual/issues/2750
-        return AwaitComplete(_remove_content(self.Cleared(self)))
+        return AwaitComplete(_remove_content())
 
     def clear_panes(self) -> AwaitComplete:
         """Remove all the panes in the tabbed content.
@@ -488,15 +479,10 @@ class TabbedContent(Widget):
             self.get_child_by_type(ContentSwitcher).remove_children(),
         )
 
-        async def _clear_content(cleared_message: TabbedContent.Cleared) -> None:
+        async def _clear_content() -> None:
             await await_clear
-            self.post_message(cleared_message)
 
-        # Note that I create the Cleared message out here, rather than in
-        # _clear_content, to ensure that the message's internal
-        # understanding of who the sender is is correct.
-        # https://github.com/Textualize/textual/issues/2750
-        return AwaitComplete(_clear_content(self.Cleared(self)))
+        return AwaitComplete(_clear_content())
 
     def compose_add_child(self, widget: Widget) -> None:
         """When using the context manager compose syntax, we want to attach nodes to the switcher.
@@ -530,6 +516,12 @@ class TabbedContent(Widget):
                 )
             )
 
+    def _on_tab_pane_focused(self, event: TabPane.Focused) -> None:
+        """One of the panes contains a widget that was programmatically focused."""
+        event.stop()
+        if event.tab_pane.id is not None:
+            self.active = event.tab_pane.id
+
     def _on_tabs_cleared(self, event: Tabs.Cleared) -> None:
         """Called when there are no active tabs. The tabs may have been cleared,
         or they may all be hidden."""
@@ -555,7 +547,7 @@ class TabbedContent(Widget):
 
     def _watch_active(self, active: str) -> None:
         """Switch tabs when the active attributes changes."""
-        with self.prevent(Tabs.TabActivated):
+        with self.prevent(Tabs.TabActivated, Tabs.Cleared):
             self.get_child_by_type(ContentTabs).active = ContentTab.add_prefix(active)
         self.get_child_by_type(ContentSwitcher).current = active
         if active:
@@ -565,6 +557,10 @@ class TabbedContent(Widget):
                     tab=self.get_child_by_type(ContentTabs).get_content_tab(active),
                 )
             )
+        else:
+            self.post_message(
+                TabbedContent.Cleared(tabbed_content=self).set_sender(self)
+            )
 
     @property
     def tab_count(self) -> int:
@@ -618,6 +614,8 @@ class TabbedContent(Widget):
 
     def _on_tabs_tab_disabled(self, event: Tabs.TabDisabled) -> None:
         """Disable the corresponding tab pane."""
+        if event.tabs.parent is not self:
+            return
         event.stop()
         tab_id = event.tab.id or ""
         try:
@@ -639,6 +637,8 @@ class TabbedContent(Widget):
 
     def _on_tabs_tab_enabled(self, event: Tabs.TabEnabled) -> None:
         """Enable the corresponding tab pane."""
+        if event.tabs.parent is not self:
+            return
         event.stop()
         tab_id = event.tab.id or ""
         try:
